about summary refs log tree commit diff
path: root/src/store.hh
diff options
context:
space:
mode:
Diffstat (limited to 'src/store.hh')
-rw-r--r--src/store.hh8
1 files changed, 4 insertions, 4 deletions
diff --git a/src/store.hh b/src/store.hh
index f747b7ee3aa8..8b02cba99681 100644
--- a/src/store.hh
+++ b/src/store.hh
@@ -13,15 +13,15 @@ void copyPath(string src, string dst);
 /* Register a path keyed on its hash. */
 Hash registerPath(const string & path, Hash hash = Hash());
 
-/* Return a path whose contents have the given hash.  If outPath is
-   not empty, ensure that such a path is realised in outPath (if
+/* Return a path whose contents have the given hash.  If target is
+   not empty, ensure that such a path is realised in target (if
    necessary by copying from another location).  If prefix is not
    empty, only return a path that is an descendent of prefix. 
 
    If no path with the given hash is known to exist in the file
-   system, ...
+   system, 
 */
-string expandHash(const Hash & hash, const string & outPath = "",
+string expandHash(const Hash & hash, const string & target = "",
     const string & prefix = "/");
 
 /* Copy a file to the nixStore directory and register it in dbRefs.